==> xfwm4-4.4.2.tar.bz2: xfwm4-4.4.2/src/keyboard.h <==
/*      $Id: keyboard.h 23704 2006-11-04 22:36:42Z olivier $

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2, or (at your option)
        any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

        oroborus - (c) 2001 Ken Lynch
        xfwm4    - (c) 2002-2006 Olivier Fourdan

 */

#ifndef INC_KEYBOARD_H
#define INC_KEYBOARD_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <X11/keysym.h>

typedef struct _MyKey MyKey;
struct _MyKey
{
    KeyCode keycode;
    int modifier;
};

extern unsigned int AltMask;
extern unsigned int MetaMask;
extern unsigned int NumLockMask;
extern unsigned int ScrollLockMask;
extern unsigned int SuperMask;
extern unsigned int HyperMask;

int                      getModifierMap                         (char *);
void                     parseKeyString                         (Display *, 
                                                                 MyKey *, 
                                                                 char *);
void                     grabKey                                (Display *, 
                                                                 MyKey *, 
                                                                 Window);
void                     ungrabKeys                             (Display *, 
                                                                 Window);
void                     grabButton                             (Display *, 
                                                                 int, 
                                                                 int, 
                                                                 Window);
void                     ungrabButton                           (Display *, 
                                                                 int, 
                                                                 int, 
                                                                 Window);
void                     initModifiers                          (Display *);

#endif /* INC_KEYBOARD_H */

==> xfwm4-4.5.91.tar.bz2: xfwm4-4.5.91/src/keyboard.h <==
/*      $Id: keyboard.h 27421 2008-08-04 20:28:44Z olivier $

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2, or (at your option)
        any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., Inc., 51 Franklin Street, Fifth Floor, Boston,
        MA 02110-1301, USA.


        oroborus - (c) 2001 Ken Lynch
        xfwm4    - (c) 2002-2008 Olivier Fourdan

 */

#ifndef INC_KEYBOARD_H
#define INC_KEYBOARD_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <X11/keysym.h>

typedef struct _MyKey MyKey;
struct _MyKey
{
    KeyCode keycode;
    int modifier;
};

extern unsigned int AltMask;
extern unsigned int MetaMask;
extern unsigned int NumLockMask;
extern unsigned int ScrollLockMask;
extern unsigned int SuperMask;
extern unsigned int HyperMask;

int                      getModifierMap                         (const char *);
void                     parseKeyString                         (Display *,
                                                                 MyKey *,
                                                                 const char *);
gboolean                 grabKey                                (Display *,
                                                                 MyKey *,
                                                                 Window);
void                     ungrabKeys                             (Display *,
                                                                 Window);
gboolean                 grabButton                             (Display *,
                                                                 int,
                                                                 int,
                                                                 Window);
void                     ungrabButton                           (Display *,
                                                                 int,
                                                                 int,
                                                                 Window);
void                     initModifiers                          (Display *);

#endif /* INC_KEYBOARD_H */
